# `oasr info`

Print information about the target skill.

```bash
oasr info <skill-name>
```

> **Note**:  
> `<skill-name>` refers to the name of the skill in the `oasr` registry.

*Display information about a skill*
![oasr info](../.images/info.png)
